@@ -2,7 +2,7 @@ package SemVer::V2::Strict;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use constant PRE_RELEASE_FORMAT    => qr/(?:-(?<pre_release>[a-zA-Z0-9.\-]+))?/;
 use constant BUILD_METADATA_FORMAT => qr/(?:\+(?<build_metadata>[a-zA-Z0-9.\-]+))?/;
@@ -66,6 +66,10 @@ sub clean {
     return eval { $class->new($version)->as_string };
 }
 
+sub sort {
+    my ($class, @versions) = @_;
+    return sort { $class->new($a) <=> $class->new($b) } @versions;
+}
 
 sub as_string {
     my $self = shift;
@@ -163,6 +167,10 @@ C<SemVer::V2::Strict-E<gt>new('1.0.0-alpha+100')> equals C<SemVer::V2::Strict-E<
 
 Clean version string. Trim spaces and C<'v'> prefix.
 
+=head3 C<sort(... $version_string)>
+
+Sort version strings.
+
 =head2 METHODS
 
 =head3 C<major>
@@ -211,7 +219,7 @@ Convert a C<SemVer::V2::Strict> instance to string.
 
 The MIT License (MIT)
 
-Copyright (c) 2015 Pine Mizune
+Copyright (c) 2015-2016 Pine Mizune
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
